@@ -3,23 +3,20 @@
 
 import abc
 import logging
-import six
 
-from typing import List, Optional  # noqa: F401
+from typing import List, Optional
 
 LOGGER = logging.getLogger(__name__)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class Callback(object):
+class Callback(object, metaclass=abc.ABCMeta):
     """
     A callback interface that expected to fire "on_success" if the operation is successful, else "on_failure" if
     operation failed.
     """
 
     @abc.abstractmethod
-    def on_success(self):
-        # type: () -> None
+    def on_success(self) -> None:
         """
         A call back method that will be called when operation is successful
         :return: None
@@ -27,8 +24,7 @@ class Callback(object):
         pass
 
     @abc.abstractmethod
-    def on_failure(self):
-        # type: () -> None
+    def on_failure(self) -> None:
         """
         A call back method that will be called when operation failed
         :return: None
@@ -36,7 +32,7 @@ class Callback(object):
         pass
 
 
-def notify_callbacks(callbacks, is_success):
+def notify_callbacks(callbacks: List[Callback], is_success: bool) -> None:
     """
     A Utility method that notifies callback. If any callback fails it will still go through all the callbacks,
     and raise the last exception it experienced.
@@ -45,7 +41,6 @@ def notify_callbacks(callbacks, is_success):
     :param is_success:
     :return:
     """
-    # type: (List[Callback], bool) -> None
 
     if not callbacks:
         LOGGER.info('No callbacks to notify')
@@ -53,7 +48,7 @@ def notify_callbacks(callbacks, is_success):
 
     LOGGER.info('Notifying callbacks')
 
-    last_exception = None  # type: Optional[Exception]
+    last_exception: Optional[Exception] = None
     for callback in callbacks:
         try:
             if is_success:
