@@ -2,9 +2,10 @@
 # SPDX-License-Identifier: Apache-2.0
 
 from cassandra.cluster import Cluster
+import cassandra.metadata
 
-from pyhocon import ConfigFactory, ConfigTree  # noqa: F401
-from typing import Iterator, Union, Dict, Any  # noqa: F401
+from pyhocon import ConfigFactory, ConfigTree
+from typing import Iterator, Union, Dict
 
 from databuilder.extractor.base_extractor import Extractor
 from databuilder.models.table_metadata import TableMetadata, ColumnMetadata
@@ -23,7 +24,7 @@ class CassandraExtractor(Extractor):
     KWARGS_KEY = 'kwargs'
     # Key to define custom filter function based on keyspace and table
     # since the cluster metadata doesn't support native filters,
-    # it should be like def filter(keyspace, table) and return False if
+    # it should be like def filter(keyspace: str, table: str) -> bool and return False if
     # going to skip that table and True if not
     FILTER_FUNCTION_KEY = 'filter'
 
@@ -35,7 +36,7 @@ class CassandraExtractor(Extractor):
         FILTER_FUNCTION_KEY: None
     })
 
-    def init(self, conf):
+    def init(self, conf: ConfigTree) -> None:
         conf = conf.with_fallback(CassandraExtractor.DEFAULT_CONFIG)
         self._cluster = '{}'.format(conf.get_string(CassandraExtractor.CLUSTER_KEY))
         self._filter = conf.get(CassandraExtractor.FILTER_FUNCTION_KEY)
@@ -43,10 +44,9 @@ class CassandraExtractor(Extractor):
         kwargs = conf.get(CassandraExtractor.KWARGS_KEY)
         self._client = Cluster(ips, **kwargs)
         self._client.connect()
-        self._extract_iter = None  # type: Union[None, Iterator]
+        self._extract_iter: Union[None, Iterator] = None
 
-    def extract(self):
-        # type: () -> Union[TableMetadata, None]
+    def extract(self) -> Union[TableMetadata, None]:
         if not self._extract_iter:
             self._extract_iter = self._get_extract_iter()
         try:
@@ -54,12 +54,10 @@ class CassandraExtractor(Extractor):
         except StopIteration:
             return None
 
-    def get_scope(self):
-        # type: () -> str
+    def get_scope(self) -> str:
         return 'extractor.cassandra'
 
-    def _get_extract_iter(self):
-        # type: () -> Iterator[TableMetadata]
+    def _get_extract_iter(self) -> Iterator[TableMetadata]:
         """
         It gets all tables and yields TableMetadata
         :return:
@@ -93,11 +91,11 @@ class CassandraExtractor(Extractor):
                     columns
                 )
 
-    def _get_keyspaces(self):
+    def _get_keyspaces(self) -> Dict[str, cassandra.metadata.KeyspaceMetadata]:
         return self._client.metadata.keyspaces
 
-    def _get_tables(self, keyspace):
+    def _get_tables(self, keyspace: str) -> Dict[str, cassandra.metadata.TableMetadata]:
         return self._client.metadata.keyspaces[keyspace].tables
 
-    def _get_columns(self, keyspace, table):
+    def _get_columns(self, keyspace: str, table: str) -> Dict[str, cassandra.metadata.ColumnMetadata]:
         return self._client.metadata.keyspaces[keyspace].tables[table].columns
