@@ -2,9 +2,9 @@
 # SPDX-License-Identifier: Apache-2.0
 
 import textwrap
-from typing import Any  # noqa: F401
+from typing import Any
 
-from pyhocon import ConfigTree  # noqa: F401
+from pyhocon import ConfigTree
 
 from databuilder import Scoped
 from databuilder.extractor.base_extractor import Extractor
@@ -33,7 +33,7 @@ class Neo4jSearchDataExtractor(Extractor):
         OPTIONAL MATCH (table)-[:TAGGED_BY]->(tags:Tag) WHERE tags.tag_type='default'
         WITH db, cluster, schema, schema_description, table, table_description, programmatic_descriptions,
         COLLECT(DISTINCT tags.key) as tags
-        OPTIONAL MATCH (table)-[:TAGGED_BY]->(badges:Tag) WHERE badges.tag_type='badge'
+        OPTIONAL MATCH (table)-[:HAS_BADGE]->(badges:Badge)
         WITH db, cluster, schema, schema_description, table, table_description, programmatic_descriptions, tags,
         COLLECT(DISTINCT badges.key) as badges
         OPTIONAL MATCH (table)-[read:READ_BY]->(user:User)
@@ -100,7 +100,7 @@ class Neo4jSearchDataExtractor(Extractor):
         OPTIONAL MATCH (dashboard)-[:TAGGED_BY]->(tags:Tag) WHERE tags.tag_type='default'
         WITH dashboard, dbg, db_descr, dbg_descr, cluster, last_exec, query_names, total_usage,
         COLLECT(DISTINCT tags.key) as tags
-        OPTIONAL MATCH (dashboard)-[:TAGGED_BY]->(badges:Tag) WHERE badges.tag_type='badge'
+        OPTIONAL MATCH (dashboard)-[:HAS_BADGE]->(badges:Badge)
         WITH  dashboard, dbg, db_descr, dbg_descr, cluster, last_exec, query_names, total_usage, tags,
         COLLECT(DISTINCT badges.key) as badges
         RETURN dbg.name as group_name, dashboard.name as name, cluster.name as cluster,
@@ -120,8 +120,7 @@ class Neo4jSearchDataExtractor(Extractor):
         'dashboard': DEFAULT_NEO4J_DASHBOARD_CYPHER_QUERY
     }
 
-    def init(self, conf):
-        # type: (ConfigTree) -> None
+    def init(self, conf: ConfigTree) -> None:
         """
         Initialize Neo4jExtractor object from configuration and use that for extraction
         """
@@ -142,33 +141,30 @@ class Neo4jSearchDataExtractor(Extractor):
         # initialize neo4j_extractor from configs
         self.neo4j_extractor.init(Scoped.get_scoped_conf(self.conf, self.neo4j_extractor.get_scope()))
 
-    def close(self):
-        # type: () -> None
+    def close(self) -> None:
         """
         Use close() method specified by neo4j_extractor
         to close connection to neo4j cluster
         """
         self.neo4j_extractor.close()
 
-    def extract(self):
-        # type: () -> Any
+    def extract(self) -> Any:
         """
         Invoke extract() method defined by neo4j_extractor
         """
         return self.neo4j_extractor.extract()
 
-    def get_scope(self):
-        # type: () -> str
+    def get_scope(self) -> str:
         return 'extractor.search_data'
 
-    def _add_publish_tag_filter(self, publish_tag, cypher_query):
+    def _add_publish_tag_filter(self, publish_tag: str, cypher_query: str) -> str:
         """
         Adds publish tag filter into Cypher query
         :param publish_tag: value of publish tag.
         :param cypher_query:
         :return:
         """
-        # type: (str, str) -> str
+
         if not publish_tag:
             publish_tag_filter = ''
         else:
