@@ -3,11 +3,10 @@
 
 
 import logging
-import six
 from collections import namedtuple
 
-from pyhocon import ConfigFactory, ConfigTree  # noqa: F401
-from typing import Iterator, Union, Dict, Any  # noqa: F401
+from pyhocon import ConfigFactory, ConfigTree
+from typing import Iterator, Union, Dict, Any
 from unidecode import unidecode
 
 from databuilder import Scoped
@@ -30,6 +29,8 @@ class SnowflakeMetadataExtractor(Extractor):
         snowflake-sqlalchemy
     """
     # SELECT statement from snowflake information_schema to extract table and column metadata
+    # https://docs.snowflake.com/en/sql-reference/account-usage.html#label-account-usage-views
+    # This can be modified to use account_usage for performance at the cost of latency if necessary.
     SQL_STATEMENT = """
     SELECT
         lower(c.column_name) AS col_name,
@@ -43,9 +44,9 @@ class SnowflakeMetadataExtractor(Extractor):
         t.comment AS description,
         decode(lower(t.table_type), 'view', 'true', 'false') AS is_view
     FROM
-        {database}.INFORMATION_SCHEMA.COLUMNS AS c
+        {database}.{schema}.COLUMNS AS c
     LEFT JOIN
-        {database}.INFORMATION_SCHEMA.TABLES t
+        {database}.{schema}.TABLES t
             ON c.TABLE_NAME = t.TABLE_NAME
             AND c.TABLE_SCHEMA = t.TABLE_SCHEMA
     {where_clause_suffix};
@@ -59,6 +60,8 @@ class SnowflakeMetadataExtractor(Extractor):
     DATABASE_KEY = 'database_key'
     # Snowflake Database Key, used to determine which Snowflake database to connect to.
     SNOWFLAKE_DATABASE_KEY = 'snowflake_database'
+    # Snowflake Schema Key, used to determine which Snowflake schema to use.
+    SNOWFLAKE_SCHEMA_KEY = 'snowflake_schema'
 
     # Default values
     DEFAULT_CLUSTER_NAME = 'master'
@@ -68,11 +71,11 @@ class SnowflakeMetadataExtractor(Extractor):
          CLUSTER_KEY: DEFAULT_CLUSTER_NAME,
          USE_CATALOG_AS_CLUSTER_NAME: True,
          DATABASE_KEY: 'snowflake',
-         SNOWFLAKE_DATABASE_KEY: 'prod'}
+         SNOWFLAKE_DATABASE_KEY: 'prod',
+         SNOWFLAKE_SCHEMA_KEY: 'INFORMATION_SCHEMA'}
     )
 
-    def init(self, conf):
-        # type: (ConfigTree) -> None
+    def init(self, conf: ConfigTree) -> None:
         conf = conf.with_fallback(SnowflakeMetadataExtractor.DEFAULT_CONFIG)
         self._cluster = '{}'.format(conf.get_string(SnowflakeMetadataExtractor.CLUSTER_KEY))
 
@@ -82,16 +85,15 @@ class SnowflakeMetadataExtractor(Extractor):
             cluster_source = "'{}'".format(self._cluster)
 
         self._database = conf.get_string(SnowflakeMetadataExtractor.DATABASE_KEY)
+        self._schema = conf.get_string(SnowflakeMetadataExtractor.DATABASE_KEY)
         self._snowflake_database = conf.get_string(SnowflakeMetadataExtractor.SNOWFLAKE_DATABASE_KEY)
-
-        if six.PY2:
-            self._database = self._database.encode('utf-8', 'ignore')
-            self._snowflake_database = self._snowflake_database.encode('utf-8', 'ignore')
+        self._snowflake_schema = conf.get_string(SnowflakeMetadataExtractor.SNOWFLAKE_SCHEMA_KEY)
 
         self.sql_stmt = SnowflakeMetadataExtractor.SQL_STATEMENT.format(
             where_clause_suffix=conf.get_string(SnowflakeMetadataExtractor.WHERE_CLAUSE_SUFFIX_KEY),
             cluster_source=cluster_source,
-            database=self._snowflake_database
+            database=self._snowflake_database,
+            schema=self._snowflake_schema
         )
 
         LOGGER.info('SQL for snowflake metadata: {}'.format(self.sql_stmt))
@@ -101,10 +103,9 @@ class SnowflakeMetadataExtractor(Extractor):
             .with_fallback(ConfigFactory.from_dict({SQLAlchemyExtractor.EXTRACT_SQL: self.sql_stmt}))
 
         self._alchemy_extractor.init(sql_alch_conf)
-        self._extract_iter = None  # type: Union[None, Iterator]
+        self._extract_iter: Union[None, Iterator] = None
 
-    def extract(self):
-        # type: () -> Union[TableMetadata, None]
+    def extract(self) -> Union[TableMetadata, None]:
         if not self._extract_iter:
             self._extract_iter = self._get_extract_iter()
         try:
@@ -112,12 +113,10 @@ class SnowflakeMetadataExtractor(Extractor):
         except StopIteration:
             return None
 
-    def get_scope(self):
-        # type: () -> str
+    def get_scope(self) -> str:
         return 'extractor.snowflake'
 
-    def _get_extract_iter(self):
-        # type: () -> Iterator[TableMetadata]
+    def _get_extract_iter(self) -> Iterator[TableMetadata]:
         """
         Using itertools.groupby and raw level iterator, it groups to table and yields TableMetadata
         :return:
@@ -141,8 +140,7 @@ class SnowflakeMetadataExtractor(Extractor):
                                 columns,
                                 last_row['is_view'] == 'true')
 
-    def _get_raw_extract_iter(self):
-        # type: () -> Iterator[Dict[str, Any]]
+    def _get_raw_extract_iter(self) -> Iterator[Dict[str, Any]]:
         """
         Provides iterator of result row from SQLAlchemy extractor
         :return:
@@ -152,8 +150,7 @@ class SnowflakeMetadataExtractor(Extractor):
             yield row
             row = self._alchemy_extractor.extract()
 
-    def _get_table_key(self, row):
-        # type: (Dict[str, Any]) -> Union[TableKey, None]
+    def _get_table_key(self, row: Dict[str, Any]) -> Union[TableKey, None]:
         """
         Table key consists of schema and table name
         :param row:
