@@ -3,10 +3,10 @@
 
 import abc
 
-from pyhocon import ConfigTree  # noqa: F401
+from pyhocon import ConfigTree
 
 from databuilder import Scoped
-from typing import Any  # noqa: F401
+from typing import Any
 
 
 class Loader(Scoped):
@@ -14,15 +14,12 @@ class Loader(Scoped):
     A loader loads to the destination or to the staging area
     """
     @abc.abstractmethod
-    def init(self, conf):
-        # type: (ConfigTree) -> None
+    def init(self, conf: ConfigTree) -> None:
         pass
 
     @abc.abstractmethod
-    def load(self, record):
-        # type: (Any) -> None
+    def load(self, record: Any) -> None:
         pass
 
-    def get_scope(self):
-        # type: () -> str
+    def get_scope(self) -> str:
         return 'loader'
