@@ -3,7 +3,7 @@
 
 import logging
 
-from typing import Optional, Dict, Any, Union, Iterator  # noqa: F401
+from typing import Optional, Dict, Any, Union, Iterator
 
 from databuilder.models.dashboard.dashboard_metadata import DashboardMetadata
 from databuilder.models.neo4j_csv_serde import (
@@ -23,13 +23,13 @@ class DashboardLastModifiedTimestamp(Neo4jCsvSerializable):
                                          '{dashboard_id}/_last_modified_timestamp'
 
     def __init__(self,
-                 dashboard_group_id,  # type: Optional[str]
-                 dashboard_id,  # type: Optional[str]
-                 last_modified_timestamp,  # type: int
-                 product='',  # type: Optional[str]
-                 cluster='gold',  # type: str
-                 **kwargs
-                 ):
+                 dashboard_group_id: Optional[str],
+                 dashboard_id: Optional[str],
+                 last_modified_timestamp: int,
+                 product: Optional[str] = '',
+                 cluster: str = 'gold',
+                 **kwargs: Any
+                 ) -> None:
         self._dashboard_group_id = dashboard_group_id
         self._dashboard_id = dashboard_id
         self._last_modified_timestamp = last_modified_timestamp
@@ -38,15 +38,13 @@ class DashboardLastModifiedTimestamp(Neo4jCsvSerializable):
         self._node_iterator = self._create_node_iterator()
         self._relation_iterator = self._create_relation_iterator()
 
-    def create_next_node(self):
-        # type: () -> Union[Dict[str, Any], None]
+    def create_next_node(self) -> Union[Dict[str, Any], None]:
         try:
             return next(self._node_iterator)
         except StopIteration:
             return None
 
-    def _create_node_iterator(self):  # noqa: C901
-        # type: () -> Iterator[[Dict[str, Any]]]
+    def _create_node_iterator(self) -> Iterator[Dict[str, Any]]:  # noqa: C901
         yield {
             NODE_LABEL: timestamp_constants.NODE_LABEL,
             NODE_KEY: self._get_last_modified_node_key(),
@@ -54,15 +52,13 @@ class DashboardLastModifiedTimestamp(Neo4jCsvSerializable):
             timestamp_constants.TIMESTAMP_NAME_PROPERTY: timestamp_constants.TimestampName.last_updated_timestamp.name,
         }
 
-    def create_next_relation(self):
-        # type: () -> Union[Dict[str, Any], None]
+    def create_next_relation(self) -> Union[Dict[str, Any], None]:
         try:
             return next(self._relation_iterator)
         except StopIteration:
             return None
 
-    def _create_relation_iterator(self):
-        # type: () -> Iterator[[Dict[str, Any]]]
+    def _create_relation_iterator(self) -> Iterator[Dict[str, Any]]:
         yield {
             RELATION_START_LABEL: DashboardMetadata.DASHBOARD_NODE_LABEL,
             RELATION_END_LABEL: timestamp_constants.NODE_LABEL,
@@ -77,7 +73,7 @@ class DashboardLastModifiedTimestamp(Neo4jCsvSerializable):
             RELATION_REVERSE_TYPE: timestamp_constants.LASTUPDATED_REVERSE_RELATION_TYPE
         }
 
-    def _get_last_modified_node_key(self):
+    def _get_last_modified_node_key(self) -> str:
         return DashboardLastModifiedTimestamp.DASHBOARD_LAST_MODIFIED_KEY_FORMAT.format(
             product=self._product,
             cluster=self._cluster,
@@ -85,7 +81,7 @@ class DashboardLastModifiedTimestamp(Neo4jCsvSerializable):
             dashboard_id=self._dashboard_id,
         )
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return 'DashboardLastModifiedTimestamp({!r}, {!r}, {!r}, {!r}, {!r})'.format(
             self._dashboard_group_id,
             self._dashboard_id,
