@@ -4,7 +4,7 @@
 import logging
 import re
 
-from typing import Optional, Dict, Any, List, Union, Iterator  # noqa: F401
+from typing import Optional, Dict, Any, List, Union, Iterator
 
 from databuilder.models.dashboard.dashboard_metadata import DashboardMetadata
 from databuilder.models.neo4j_csv_serde import (
@@ -27,13 +27,13 @@ class DashboardTable(Neo4jCsvSerializable):
     TABLE_DASHBOARD_RELATION_TYPE = 'TABLE_OF_DASHBOARD'
 
     def __init__(self,
-                 dashboard_group_id,  # type: str
-                 dashboard_id,  # type: str
-                 table_ids,  # type: List[str]
-                 product='',  # type: Optional[str]
-                 cluster='gold',  # type: str
-                 **kwargs
-                 ):
+                 dashboard_group_id: str,
+                 dashboard_id: str,
+                 table_ids: List[str],
+                 product: Optional[str] = '',
+                 cluster: str = 'gold',
+                 **kwargs: Any
+                 ) -> None:
         self._dashboard_group_id = dashboard_group_id
         self._dashboard_id = dashboard_id
         # A list of tables uri used in the dashboard
@@ -43,21 +43,21 @@ class DashboardTable(Neo4jCsvSerializable):
 
         self._relation_iterator = self._create_relation_iterator()
 
-    def create_next_node(self):
-        # type: () -> Union[Dict[str, Any], None]
+    def create_next_node(self) -> Union[Dict[str, Any], None]:
         return None
 
-    def create_next_relation(self):
-        # type: () -> Union[Dict[str, Any], None]
+    def create_next_relation(self) -> Union[Dict[str, Any], None]:
+        if self._relation_iterator is None:
+            return None
+
         try:
             return next(self._relation_iterator)
         except StopIteration:
             return None
 
-    def _create_relation_iterator(self):
-        # type: () -> Optional[None, Iterator[[Dict[str, Any]]]]
+    def _create_relation_iterator(self) -> Optional[Iterator[Dict[str, Any]]]:
         for table_id in self._table_ids:
-            m = re.match('(\w+)://(\w+)\.(\w+)\/(\w+)', table_id)
+            m = re.match('([^./]+)://([^./]+)\.([^./]+)\/([^./]+)', table_id)
             if m:
                 yield {
                     RELATION_START_LABEL: DashboardMetadata.DASHBOARD_NODE_LABEL,
@@ -78,7 +78,7 @@ class DashboardTable(Neo4jCsvSerializable):
                     RELATION_REVERSE_TYPE: DashboardTable.TABLE_DASHBOARD_RELATION_TYPE
                 }
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return 'DashboardTable({!r}, {!r}, {!r}, {!r}, ({!r}))'.format(
             self._dashboard_group_id,
             self._dashboard_id,
