@@ -3,8 +3,7 @@
 
 import abc
 
-import six
-from typing import Dict, Set, Any, Union  # noqa: F401
+from typing import Dict, Set, Any, Union
 
 NODE_KEY = 'KEY'
 NODE_LABEL = 'LABEL'
@@ -24,8 +23,7 @@ LABELS = {NODE_LABEL, RELATION_START_LABEL, RELATION_END_LABEL}
 TYPES = {RELATION_TYPE, RELATION_REVERSE_TYPE}
 
 
-@six.add_metaclass(abc.ABCMeta)
-class Neo4jCsvSerializable(object):
+class Neo4jCsvSerializable(object, metaclass=abc.ABCMeta):
     """
     A Serializable abstract class asks subclass to implement next node or
     next relation in dict form so that it can be serialized to CSV file.
@@ -33,13 +31,11 @@ class Neo4jCsvSerializable(object):
     Any model class that needs to be pushed to Neo4j should inherit this class.
     """
 
-    def __init__(self):
-        # type: () -> None
+    def __init__(self) -> None:
         pass
 
     @abc.abstractmethod
-    def create_next_node(self):
-        # type: () -> Union[Dict[str, Any], None]
+    def create_next_node(self) -> Union[Dict[str, Any], None]:
         """
         Creates dict where keys represent header in CSV and value represents
         row in CSV file. Should the class could have different types of
@@ -55,8 +51,7 @@ class Neo4jCsvSerializable(object):
         raise NotImplementedError
 
     @abc.abstractmethod
-    def create_next_relation(self):
-        # type: () -> Union[Dict[str, Any], None]
+    def create_next_relation(self) -> Union[Dict[str, Any], None]:
         """
         Creates dict where keys represent header in CSV and value represents
         row in CSV file. Should the class could have different types of
@@ -71,8 +66,7 @@ class Neo4jCsvSerializable(object):
         """
         raise NotImplementedError
 
-    def next_node(self):
-        # type: () -> Union[Dict[str, Any], None]
+    def next_node(self) -> Union[Dict[str, Any], None]:
         """
         Provides node(vertex) in dict form.
         Note that subsequent call can create different header (dict.keys())
@@ -88,8 +82,7 @@ class Neo4jCsvSerializable(object):
         self._validate(NODE_REQUIRED_HEADERS, node_dict)
         return node_dict
 
-    def next_relation(self):
-        # type: () -> Union[Dict[str, Any], None]
+    def next_relation(self) -> Union[Dict[str, Any], None]:
         """
         Provides relation(edge) in dict form.
         Note that subsequent call can create different header (dict.keys())
@@ -105,8 +98,9 @@ class Neo4jCsvSerializable(object):
         self._validate(RELATION_REQUIRED_HEADERS, relation_dict)
         return relation_dict
 
-    def _validate(self, required_set, val_dict):
-        # type: (Set[str], Dict[str, Any]) -> None
+    def _validate(self,
+                  required_set: Set[str],
+                  val_dict: Dict[str, Any]) -> None:
         """
         Validates dict that represents CSV header and a row.
          - Checks if it has required headers for either Node or Relation
@@ -120,7 +114,7 @@ class Neo4jCsvSerializable(object):
         required_count = 0
         for header_col, val_col in \
                 ((header_col, val_col) for header_col, val_col
-                 in six.iteritems(val_dict) if header_col in required_set):
+                 in val_dict.items() if header_col in required_set):
             required_count += 1
 
             if header_col in LABELS:
@@ -131,7 +125,7 @@ class Neo4jCsvSerializable(object):
             elif header_col in TYPES:
                 if not val_col == val_col.upper():
                     raise RuntimeError(
-                        'TYPE needs to be upper case: '.format(val_col))
+                        'TYPE needs to be upper case: {}'.format(val_col))
 
         if required_count != len(required_set):
             raise RuntimeError(
