@@ -2,7 +2,7 @@
 # SPDX-License-Identifier: Apache-2.0
 
 import re
-from typing import Any, Dict, List, Union  # noqa: F401
+from typing import Any, Dict, List, Union
 
 from databuilder.models.neo4j_csv_serde import Neo4jCsvSerializable, \
     RELATION_START_KEY, RELATION_START_LABEL, RELATION_END_KEY, \
@@ -12,7 +12,6 @@ from databuilder.models.table_metadata import TableMetadata
 
 
 class TableLineage(Neo4jCsvSerializable):
-    # type: (...) -> None
     """
     Table Lineage Model. It won't create nodes but create upstream/downstream rels.
     """
@@ -22,13 +21,12 @@ class TableLineage(Neo4jCsvSerializable):
     DEPENDENCY_ORIGIN_RELATION_TYPE = 'DOWNSTREAM'
 
     def __init__(self,
-                 db_name,  # type: str
-                 schema,  # type: str
-                 table_name,  # type: str
-                 cluster,  # type: str
-                 downstream_deps=None,  # type: List
-                 ):
-        # type: (...) -> None
+                 db_name: str,
+                 schema: str,
+                 table_name: str,
+                 cluster: str,
+                 downstream_deps: List=None,
+                 ) -> None:
         self.db = db_name.lower()
         self.schema = schema.lower()
         self.table = table_name.lower()
@@ -36,42 +34,42 @@ class TableLineage(Neo4jCsvSerializable):
         self.cluster = cluster.lower() if cluster else 'gold'
         # a list of downstream dependencies, each of which will follow
         # the same key
-        self.downstream_deps = downstream_deps
+        self.downstream_deps = downstream_deps or []
         self._node_iter = iter(self.create_nodes())
         self._relation_iter = iter(self.create_relation())
 
-    def create_next_node(self):
-        # type: (...) -> Union[Dict[str, Any], None]
+    def create_next_node(self) -> Union[Dict[str, Any], None]:
         # return the string representation of the data
         try:
             return next(self._node_iter)
         except StopIteration:
             return None
 
-    def create_next_relation(self):
-        # type: (...) -> Union[Dict[str, Any], None]
+    def create_next_relation(self) -> Union[Dict[str, Any], None]:
         try:
             return next(self._relation_iter)
         except StopIteration:
             return None
 
-    def get_table_model_key(self, db, cluster, schema, table):
-        # type: (...) -> str
+    def get_table_model_key(self,
+                            db: str,
+                            cluster: str,
+                            schema: str,
+                            table: str
+                            ) -> str:
         return '{db}://{cluster}.{schema}/{table}'.format(db=db,
                                                           cluster=cluster,
                                                           schema=schema,
                                                           table=table)
 
-    def create_nodes(self):
-        # type: () -> List[Union[Dict[str, Any], None]]
+    def create_nodes(self) -> List[Union[Dict[str, Any], None]]:
         """
         It won't create any node for this model
         :return:
         """
         return []
 
-    def create_relation(self):
-        # type: () -> List[Dict[str, Any]]
+    def create_relation(self) -> List[Dict[str, Any]]:
         """
         Create a list of relation between source table and all the downstream tables
         :return:
@@ -99,8 +97,7 @@ class TableLineage(Neo4jCsvSerializable):
                 })
         return results
 
-    def __repr__(self):
-        # type: () -> str
+    def __repr__(self) -> str:
         return 'TableLineage({!r}, {!r}, {!r}, {!r})'.format(self.db,
                                                              self.cluster,
                                                              self.schema,
