@@ -3,9 +3,8 @@
 
 import copy
 from collections import namedtuple
-from six import string_types
 
-from typing import Iterable, Any, Union, Iterator, Dict, Set  # noqa: F401
+from typing import Any, Dict, Iterable, Iterator, List, Optional, Set, Union
 
 from databuilder.models.cluster import cluster_constants
 from databuilder.models.neo4j_csv_serde import (
@@ -28,37 +27,36 @@ class TagMetadata(Neo4jCsvSerializable):
     METRIC_TYPE = 'metric'
 
     def __init__(self,
-                 name,  # type: str,
-                 tag_type='default',  # type: str
+                 name: str,
+                 tag_type: str = 'default',
                  ):
         self._name = name
         self._tag_type = tag_type
         self._nodes = iter([self.create_tag_node(self._name, self._tag_type)])
-        self._relations = iter([])
+        self._relations: Iterator[Dict[str, Any]] = iter([])
 
     @staticmethod
-    def get_tag_key(name):
-        # type: (str) -> str
+    def get_tag_key(name: str) -> str:
         if not name:
             return ''
         return TagMetadata.TAG_KEY_FORMAT.format(tag=name)
 
     @staticmethod
-    def create_tag_node(name, tag_type=DEFAULT_TYPE):
+    def create_tag_node(name: str,
+                        tag_type: str =DEFAULT_TYPE
+                        ) -> Dict[str, str]:
         return {NODE_LABEL: TagMetadata.TAG_NODE_LABEL,
                 NODE_KEY: TagMetadata.get_tag_key(name),
                 TagMetadata.TAG_TYPE: tag_type}
 
-    def create_next_node(self):
-        # type: (...) -> Union[Dict[str, Any], None]
+    def create_next_node(self) -> Optional[Dict[str, Any]]:
         # return the string representation of the data
         try:
             return next(self._nodes)
         except StopIteration:
             return None
 
-    def create_next_relation(self):
-        # type: () -> Union[Dict[str, Any], None]
+    def create_next_relation(self) -> Optional[Dict[str, Any]]:
         # We don't emit any relations for Tag ingestion
         try:
             return next(self._relations)
@@ -66,6 +64,7 @@ class TagMetadata(Neo4jCsvSerializable):
             return None
 
 
+# TODO: this should inherit from ProgrammaticDescription in amundsen-common
 class DescriptionMetadata:
     DESCRIPTION_NODE_LABEL = DESCRIPTION_NODE_LABEL_VAL
     PROGRAMMATIC_DESCRIPTION_NODE_LABEL = 'Programmatic_Description'
@@ -80,8 +79,8 @@ class DescriptionMetadata:
     DEFAULT_SOURCE = "description"
 
     def __init__(self,
-                 text,  # type: Union[None, str]
-                 source=DEFAULT_SOURCE  # type: str
+                 text: Optional[str],
+                 source: str = DEFAULT_SOURCE
                  ):
         """
         :param source: The unique source of what is populating this description.
@@ -96,9 +95,9 @@ class DescriptionMetadata:
             self._label = self.PROGRAMMATIC_DESCRIPTION_NODE_LABEL
 
     @staticmethod
-    def create_description_metadata(text, source=DEFAULT_SOURCE):
-        # type: (Union[None,str], str) -> ProgrammaticDescription
-
+    def create_description_metadata(text: Union[None, str],
+                                    source: Optional[str] = DEFAULT_SOURCE
+                                    ) -> Optional['DescriptionMetadata']:
         # We do not want to create a node if there is no description text!
         if text is None:
             return None
@@ -108,28 +107,30 @@ class DescriptionMetadata:
             description_node = DescriptionMetadata(text=text, source=source)
         return description_node
 
-    def get_description_id(self):
-        # type: () -> str
+    def get_description_id(self) -> str:
         if self._source == self.DEFAULT_SOURCE:
             return "_description"
         else:
             return "_" + self._source + "_description"
 
-    def __repr__(self):
-        # type: () -> str
+    def __repr__(self) -> str:
         return 'DescriptionMetadata({!r}, {!r})'.format(self._source, self._text)
 
-    def get_node_dict(self, node_key):
-        # (str) -> Dict
+    def get_node_dict(self,
+                      node_key: str
+                      ) -> Dict[str, str]:
         return {
             NODE_LABEL: self._label,
             NODE_KEY: node_key,
             DescriptionMetadata.DESCRIPTION_SOURCE: self._source,
-            DescriptionMetadata.DESCRIPTION_TEXT: self._text,
+            DescriptionMetadata.DESCRIPTION_TEXT: self._text or '',
         }
 
-    def get_relation(self, start_node, start_key, end_key):
-        # (str, str) => Dict
+    def get_relation(self,
+                     start_node: str,
+                     start_key: str,
+                     end_key: str
+                     ) -> Dict[str, str]:
         return {
             RELATION_START_LABEL: start_node,
             RELATION_END_LABEL: self._label,
@@ -154,13 +155,12 @@ class ColumnMetadata:
     TAG_COL_RELATION_TYPE = 'TAG'
 
     def __init__(self,
-                 name,  # type: str
-                 description,  # type: Union[str, None]
-                 col_type,  # type: str
-                 sort_order,  # type: int
-                 tags=None  # type: Union[List[str], None]
-                 ):
-        # type: (...) -> None
+                 name: str,
+                 description: Union[str, None],
+                 col_type: str,
+                 sort_order: int,
+                 tags: Union[List[str], None] = None
+                 ) -> None:
         """
         TODO: Add stats
         :param name:
@@ -175,8 +175,7 @@ class ColumnMetadata:
         self.sort_order = sort_order
         self.tags = tags
 
-    def __repr__(self):
-        # type: () -> str
+    def __repr__(self) -> str:
         return 'ColumnMetadata({!r}, {!r}, {!r}, {!r})'.format(self.name,
                                                                self.description,
                                                                self.type,
@@ -228,22 +227,21 @@ class TableMetadata(Neo4jCsvSerializable):
     TAG_TABLE_RELATION_TYPE = 'TAG'
 
     # Only for deduping database, cluster, and schema (table and column will be always processed)
-    serialized_nodes = set()  # type: Set[Any]
-    serialized_rels = set()  # type: Set[Any]
+    serialized_nodes: Set[Any] = set()
+    serialized_rels: Set[Any] = set()
 
     def __init__(self,
-                 database,  # type: str
-                 cluster,  # type: str
-                 schema,  # type: str
-                 name,  # type: str
-                 description,  # type: Union[str, None]
-                 columns=None,  # type: Iterable[ColumnMetadata]
-                 is_view=False,  # type: bool
-                 tags=None,  # type: Union[List, str]
-                 description_source=None,  # type: Union[str, None]
-                 **kwargs  # type: Dict
-                 ):
-        # type: (...) -> None
+                 database: str,
+                 cluster: str,
+                 schema: str,
+                 name: str,
+                 description: Union[str, None],
+                 columns: Iterable[ColumnMetadata] = None,
+                 is_view: bool = False,
+                 tags: Union[List, str] = None,
+                 description_source: Union[str, None] = None,
+                 **kwargs: Any
+                 ) -> None:
         """
         :param database:
         :param cluster:
@@ -263,7 +261,7 @@ class TableMetadata(Neo4jCsvSerializable):
         self.description = DescriptionMetadata.create_description_metadata(text=description, source=description_source)
         self.columns = columns if columns else []
         self.is_view = is_view
-        self.attrs = None
+        self.attrs: Optional[Dict[str, Any]] = None
 
         self.tags = TableMetadata.format_tags(tags)
 
@@ -273,8 +271,7 @@ class TableMetadata(Neo4jCsvSerializable):
         self._node_iterator = self._create_next_node()
         self._relation_iterator = self._create_next_relation()
 
-    def __repr__(self):
-        # type: () -> str
+    def __repr__(self) -> str:
         return 'TableMetadata({!r}, {!r}, {!r}, {!r} ' \
                '{!r}, {!r}, {!r}, {!r})'.format(self.database,
                                                 self.cluster,
@@ -285,46 +282,42 @@ class TableMetadata(Neo4jCsvSerializable):
                                                 self.is_view,
                                                 self.tags)
 
-    def _get_table_key(self):
-        # type: () -> str
+    def _get_table_key(self) -> str:
         return TableMetadata.TABLE_KEY_FORMAT.format(db=self.database,
                                                      cluster=self.cluster,
                                                      schema=self.schema,
                                                      tbl=self.name)
 
-    def _get_table_description_key(self, description):
-        # type: (DescriptionMetadata) -> str
+    def _get_table_description_key(self,
+                                   description: DescriptionMetadata) -> str:
         return TableMetadata.TABLE_DESCRIPTION_FORMAT.format(db=self.database,
                                                              cluster=self.cluster,
                                                              schema=self.schema,
                                                              tbl=self.name,
                                                              description_id=description.get_description_id())
 
-    def _get_database_key(self):
-        # type: () -> str
+    def _get_database_key(self) -> str:
         return TableMetadata.DATABASE_KEY_FORMAT.format(db=self.database)
 
-    def _get_cluster_key(self):
-        # type: () -> str
+    def _get_cluster_key(self) -> str:
         return TableMetadata.CLUSTER_KEY_FORMAT.format(db=self.database,
                                                        cluster=self.cluster)
 
-    def _get_schema_key(self):
-        # type: () -> str
+    def _get_schema_key(self) -> str:
         return TableMetadata.SCHEMA_KEY_FORMAT.format(db=self.database,
                                                       cluster=self.cluster,
                                                       schema=self.schema)
 
-    def _get_col_key(self, col):
-        # type: (ColumnMetadata) -> str
+    def _get_col_key(self, col: ColumnMetadata) -> str:
         return ColumnMetadata.COLUMN_KEY_FORMAT.format(db=self.database,
                                                        cluster=self.cluster,
                                                        schema=self.schema,
                                                        tbl=self.name,
                                                        col=col.name)
 
-    def _get_col_description_key(self, col, description):
-        # type: (ColumnMetadata, DescriptionMetadata) -> str
+    def _get_col_description_key(self,
+                                 col: ColumnMetadata,
+                                 description: DescriptionMetadata) -> str:
         return ColumnMetadata.COLUMN_DESCRIPTION_FORMAT.format(db=self.database,
                                                                cluster=self.cluster,
                                                                schema=self.schema,
@@ -333,22 +326,23 @@ class TableMetadata(Neo4jCsvSerializable):
                                                                description_id=description.get_description_id())
 
     @staticmethod
-    def format_tags(tags):
-        if isinstance(tags, string_types):
+    def format_tags(tags: Union[List, str, None]) -> List:
+        if tags is None:
+            tags = []
+        if isinstance(tags, str):
             tags = list(filter(None, tags.split(',')))
         if isinstance(tags, list):
             tags = [tag.lower().strip() for tag in tags]
+
         return tags
 
-    def create_next_node(self):
-        # type: () -> Union[Dict[str, Any], None]
+    def create_next_node(self) -> Union[Dict[str, Any], None]:
         try:
             return next(self._node_iterator)
         except StopIteration:
             return None
 
-    def _create_next_node(self):  # noqa: C901
-        # type: () -> Iterator[Any]
+    def _create_next_node(self) -> Iterator[Any]:  # noqa: C901
 
         table_node = {NODE_LABEL: TableMetadata.TABLE_NODE_LABEL,
                       NODE_KEY: self._get_table_key(),
@@ -408,15 +402,13 @@ class TableMetadata(Neo4jCsvSerializable):
                     'name': node_tuple.name
                 }
 
-    def create_next_relation(self):
-        # type: () -> Union[Dict[str, Any], None]
+    def create_next_relation(self) -> Union[Dict[str, Any], None]:
         try:
             return next(self._relation_iterator)
         except StopIteration:
             return None
 
-    def _create_next_relation(self):
-        # type: () -> Iterator[Any]
+    def _create_next_relation(self) -> Iterator[Any]:
 
         yield {
             RELATION_START_LABEL: TableMetadata.SCHEMA_NODE_LABEL,
